@@ -1,8 +1,8 @@
 /* vim: set noet ts=4:
- * $Id: wmweather.c,v 1.89 2004/07/11 15:34:21 godisch Exp $
+ * $Id: wmweather.c,v 1.91 2007/05/13 17:27:21 martin Exp $
  *
  * Copyright (c) 1999 Michael G. Henderson <mghenderson@lanl.gov>.
- * Copyright (c) 2002-2003 Martin A. Godisch <martin@godisch.de>.
+ * Copyright (c) 2002-2007 Martin A. Godisch <martin@godisch.de>.
  *
  * This program is free software; you can redistribute it and/or modify it under
  * the terms of the GNU General Public License as published by the Free Software
@@ -117,11 +117,11 @@ int main(int argc, char *argv[])
 	if (chdir(report)) {
 		if (errno == ENOENT) {
 			if (mkdir(report, 0777)) {
-				fprintf(stderr, "%s: cannot create %s: %s\n", PACKAGE_NAME, report, strerror(errno));
+				fprintf(stderr, "%s: cannot create %s: %m\n", PACKAGE_NAME, report);
 				exit(errno);
 			}
 		} else {
-			fprintf(stderr, "%s: cannot chdir into %s: %s\n", PACKAGE_NAME, report, strerror(errno));
+			fprintf(stderr, "%s: cannot chdir into %s: %m\n", PACKAGE_NAME, report);
 			exit(errno);
 		}
 	}
@@ -142,7 +142,7 @@ int main(int argc, char *argv[])
 
 	for (i = 0; signals[i]; i++)
 		if (signal(signals[i], handler) == SIG_ERR)
-			fprintf(stderr, "%s: cannot set handler for signal %d: %s\n", PACKAGE_NAME, signals[i], strerror(errno));
+			fprintf(stderr, "%s: cannot set handler for signal %d: %m\n", PACKAGE_NAME, signals[i]);
 
 	assert(curl_errmsg);
 	memset(curl_errmsg, 0, CURL_ERROR_SIZE);
@@ -220,14 +220,14 @@ static void display_report(void)
 	if (xmsg_child)
 		return;
 	if ((xmsg_child = fork()) < 0) {
-		fprintf(stderr, "%s: cannot fork: %s\n", PACKAGE_NAME, strerror(errno));
+		fprintf(stderr, "%s: cannot fork: %m\n", PACKAGE_NAME);
 		xmsg_child = 0;
 		return;
 	}
 	if (xmsg_child)
 		return;
 	if (execl(XMESSAGE, "xmessage", "-center", "-file", report, "-title", xtitle, NULL) < 0) {
-		fprintf(stderr, "%s (pid %d): error executing xmessage: %s\n", PACKAGE_NAME, getpid(), strerror(errno));
+		fprintf(stderr, "%s (pid %d): error executing xmessage: %m\n", PACKAGE_NAME, getpid());
 		exit(1);
 	}
 }
@@ -246,7 +246,7 @@ static void do_conf(const char *rcfile)
 
 	if ((F = fopen(rcfile, "r")) == NULL) {
 		if (errno != ENOENT)
-			fprintf(stderr, "%s: cannot open %s: %s\n", PACKAGE_NAME, rcfile, strerror(errno));
+			fprintf(stderr, "%s: cannot open %s: %m\n", PACKAGE_NAME, rcfile);
 		return;
 	}
 	for (line = 1;; line++) {
@@ -524,7 +524,7 @@ static void do_opts(int argc, char *argv[])
 		case 'v':
 			printf("%s\n", PACKAGE_STRING);
 			printf("copyright (c) 1999 Michael G. Henderson <mghenderson@lanl.gov>\n");
-			printf("copyright (c) 2002-2003 Martin A. Godisch <martin@godisch.de>\n");
+			printf("copyright (c) 2002-2007 Martin A. Godisch <martin@godisch.de>\n");
 			exit(0);
 		case 0:
 		case 1:
@@ -574,7 +574,7 @@ static void grab_weather(void)
 		sprintf(temp, "%s.new", report);
 	}
 	if ((F = fopen(temp, "w")) == NULL) {
-		fprintf(stderr, "%s: cannot open %s for writing: %s\n", PACKAGE_NAME, temp, strerror(errno));
+		fprintf(stderr, "%s: cannot open %s for writing: %m\n", PACKAGE_NAME, temp);
 		goto GRAB_ERR;
 	}
 	if (curl_easy_setopt(curl, CURLOPT_FILE, F)) {
@@ -591,7 +591,7 @@ static void grab_weather(void)
 			/* FIXME: what to do here? */
 		} else if (http < 300) { /* 2xx - Success       */
 			if (rename(temp, report) < 0) {
-				fprintf(stderr, "%s: Cannot rename %s to %s: %s\n", PACKAGE_NAME, temp, report, strerror(errno));
+				fprintf(stderr, "%s: Cannot rename %s to %s: %m\n", PACKAGE_NAME, temp, report);
 				goto GRAB_ERR;
 			}
 		} else if (http < 400) { /* 3xx - Redirection   */
@@ -690,7 +690,6 @@ static void update(int force_read)
 	char   buffer[MAX_STRING], *i;
 	int    line, n, q, sgn;
 	long   l = 0;
-	double d;
 
 	time(&l);
 	tm = gmtime(&l);
@@ -700,7 +699,7 @@ static void update(int force_read)
 
 	if (stat(report, &rst) < 0 && errno != ENOENT) {
 		if (showerror) {
-			fprintf(stderr, "%s: cannot stat weather report %s: %s\n", PACKAGE_NAME, report, strerror(errno));
+			fprintf(stderr, "%s: cannot stat weather report %s: %m\n", PACKAGE_NAME, report);
 			showerror = 0;
 		}
 		return;
@@ -710,7 +709,7 @@ static void update(int force_read)
 		F = fopen(report, "r");
 		if (!F) {
 			if (showerror && errno != ENOENT) {
-				fprintf(stderr, "%s: cannot open weather report %s: %s\n", PACKAGE_NAME, report, strerror(errno));
+				fprintf(stderr, "%s: cannot open weather report %s: %m\n", PACKAGE_NAME, report);
 				showerror = 0;
 			}
 			return;
@@ -891,34 +890,34 @@ static void update(int force_read)
 			}
 
 			if (!strncmp(buffer, "Temperature: ", 13)) {
+				double t;
 				i = buffer + 13;
-				temperature = strtol(i, &i, 10);
-				if (*i != ' ' && *i != '.') {
+				t = strtod(i, &i);
+				if (*i != ' ') {
 					if (showerror)
 						fprintf(stderr, "%s: invalid temperature: %s line %d\n", PACKAGE_NAME, report, line);
 					continue;
 				}
 				temperatureavail = 1;
-				if (metric) {
-					d = (temperature - 32.0) * 5.0 / 9.0;
-					temperature = (d < 0) ? d - 0.5 : d + 0.5;
-				}
+				if (metric)
+					t = (t - 32.0) * 5.0 / 9.0;
+				temperature = (t < 0) ? t - 0.5 : t + 0.5;
 				continue;
 			}
 
 			if (!strncmp(buffer, "Dew Point: ", 11)) {
+				double d;
 				i = buffer + 11;
-				dewpoint = strtol(i, &i, 10);
-				if (*i != ' ' && *i != '.') {
+				d = strtod(i, &i);
+				if (*i != ' ') {
 					if (showerror)
 						fprintf(stderr, "%s: invalid dew point: %s line %d\n", PACKAGE_NAME, report, line);
 					continue;
 				}
 				dewpointavail = 1;
-				if (metric) {
-					d = (dewpoint - 32.0) * 5.0 / 9.0;
-					dewpoint = (d < 0) ? d - 0.5 : d + 0.5;
-				}
+				if (metric)
+					d = (d - 32.0) * 5.0 / 9.0;
+				dewpoint = (d < 0) ? d - 0.5 : d + 0.5;
 				continue;
 			}
 
